@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef __CHEESE_H__
@@ -25,11 +24,13 @@
 #include <gtk/gtk.h>
 
 //FIXME: provide option to choose the folder
-#define SAVE_FOLDER_DEFAULT  	 "images/"
-#define PHOTO_NAME_DEFAULT	 "Picture"
+#define PHOTO_FOLDER_DEFAULT  	  "images/"
+#define PHOTO_NAME_DEFAULT	      "Picture"
 #define PHOTO_NAME_SUFFIX_DEFAULT ".jpg"
+#define VIDEO_FOLDER_DEFAULT  	  "videos/"
+#define VIDEO_NAME_DEFAULT	      "Video"
+#define VIDEO_NAME_SUFFIX_DEFAULT ".ogg"
 
-
-void on_cheese_window_close_cb(GtkWidget *widget, gpointer data);
+void on_cheese_window_close_cb (GtkWidget *, gpointer);
 
 #endif /* __CHEESE_H__ */
